import { useState, useEffect } from "react";

// Helper function to check real connectivity
const checkConnectivity = async (): Promise<boolean> => {
  if (!navigator.onLine) {
    return false; // Clearly offline
  }
  try {
    const response = await fetch("https://api.medianet.com.pk?_=" + new Date().getTime(), {
      method: "GET", // *GET, POST, PUT, DELETE, etc.
      mode: "no-cors",
      cache: "no-store", // Prevent serving cached responses
    })
      .then((res) => {
        return res.status == 0 ? true : false; // True if the request succeeds
      })
      .catch((error) => {
        if (error.message == "Failed to fetch") {
          return false;
        }
        return true;
      }); // Fetch the favicon to check for connectivity
    return response;
  } catch (error) {
    return false; // False if there's any network failure
  }
};

const useNetworkStatus = (): boolean => {
  const [isOnline, setIsOnline] = useState<boolean>(true);

  // Update online status using both `navigator.onLine` and `checkConnectivity`
  const updateStatus = async (): Promise<void> => {
    const online = await checkConnectivity();
    setIsOnline(online);
  };

  useEffect(() => {
    // Initial connectivity check
    updateStatus();

    // Event listeners for network status changes
    const handleOnline = () => updateStatus();
    const handleOffline = () => setIsOnline(false);

    window.addEventListener("online", handleOnline);
    window.addEventListener("offline", handleOffline);

    // Cleanup listeners on unmount
    return () => {
      window.removeEventListener("online", handleOnline);
      window.removeEventListener("offline", handleOffline);
    };
  }, []);

  return isOnline;
};

export default useNetworkStatus;
